<?php
/**
 * Coffee Shop functions and definitions
 *
 * @package Coffee Shop
 */

/**
 * The current version of the theme.
 */
define( 'COFFEE_VERSION', '1.3.1' );

/**
 * Sets the content width in pixels.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function coffee_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'coffee_content_width', 936 );
}
add_action( 'after_setup_theme', 'coffee_content_width', 0 );

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function coffee_setup() {
	// Make theme available for translation.
	load_theme_textdomain( 'coffee-shop', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	// Let WordPress manage the document title.
	add_theme_support( 'title-tag' );

	// Enable support for theme logo.
	add_theme_support( 'custom-logo', array(
		'width'       => 648,
		'height'      => 324,
		'flex-width'  => true,
		'flex-height' => true,
		'header-text' => true,
	) );

	// Enable support for Post Thumbnails on posts and pages.
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'custom-background' );
	$args = array(
        
        'default-text-color' => '000',
        'width'              => 1000,
        'height'             => 250,
        'flex-width'         => true,
        'flex-height'        => true,
    );
   add_theme_support( 'custom-header', $args );

	// Add necessary image sizes.
	add_image_size( 'coffee-thumbnail', 612, 0, false );
	add_image_size( 'coffee-thumbnail-2x', 1224, 0, false );

	add_image_size( 'coffee-thumbnail-full', 936, 0, false );
	add_image_size( 'coffee-thumbnail-full-2x', 1872, 0, false );

	add_image_size( 'coffee-panel', 1440, 0, false );
	add_image_size( 'coffee-panel-2x', 2880, 0, false );
	add_image_size( 'coffee-panel-half', 720, 0, false );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary', 'coffee-shop' ),
	) );

	// Switch default core markup to output valid HTML5 for listed components.
	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Add support for Jetpack responsive videos.
	add_theme_support( 'jetpack-responsive-videos' );

	// Add support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	// This theme styles the visual editor to resemble theme styles.
	add_editor_style( array( 'assets/css/editor-style.css' ) );

	// Define and register starter content to showcase the theme on new sites.
	$starter_content = array(
		// Add pages.
		'posts' => array(
			'about' => array(
					'post_title' => esc_html_x( 'About', 'Theme starter content', 'coffee-shop' ),
					'post_content' => join( '', array(
					'<p>' . esc_html_x( 'We are proud of our coffee shop with the highest-quality products, most inviting stores, friendliest staff and the best coffee in the world.', 'Theme starter content', 'coffee-shop' ) . '</p>',
				) ),
			),
			'blog',
			'contact' => array(
					'post_title' => esc_html_x( 'Contact Us', 'Theme starter content', 'coffee-shop' ),
					'post_content' => join( '', array(
					'<p>' . esc_html_x( 'This is a page with some basic contact information, such as an address and phone number. You might also try a plugin to add a contact form.', 'Theme starter content', 'coffee-shop' ) . '</p>',
				) ),
			),
			'hero' => array(
				'post_type' => 'page',
				'post_title' => esc_html_x( 'Small Cafe in the Heart of City!', 'Theme starter content', 'coffee-shop' ),
				'post_content' => join( '', array(
					'<p>' . esc_html_x( 'We are proud of our coffee shop with the highest-quality products, most inviting stores, friendliest staff and the best coffee in the world.', 'Theme starter content', 'coffee-shop' ) . '</p>',
					'<p><a href="#panel-1" class="btn btn-default">' . esc_html_x( 'View the Menu', 'Theme starter content', 'coffee-shop' ) . '</a></p>',
				) ),
			),
			'menu' => array(
				'post_type' => 'page',
				'post_title' => esc_html_x( 'Menu Restaurant', 'Theme starter content', 'coffee-shop' ),
				'post_content' => join( '', array(
					'<h5>' . esc_html_x( 'BURGERS', 'Theme starter content', 'coffee-shop' ) . '</h5><p>' . esc_html_x( 'Beef Meat 5.25', 'Theme starter content', 'coffee-shop' ).'<br>'. esc_html_x( 'Chicken Meat $6.76', 'Theme starter content', 'coffee-shop' ).'<br>'. esc_html_x( 'Cheeseburger 5.35', 'Theme starter content', 'coffee-shop' ).'<br>'. esc_html_x( 'Vegan 4.99', 'Theme starter content', 'coffee-shop' ). '</p>',
					'<h5>' . esc_html_x( 'DRINKS', 'Theme starter content', 'coffee-shop' ) . '</h5><p>' . esc_html_x( 'Coca-Cola 10.25', 'Theme starter content', 'coffee-shop' ).'<br>'. esc_html_x( 'Sprite 8.75', 'Theme starter content', 'coffee-shop' ).'<br>'. esc_html_x( 'Mineral Water 5.99', 'Theme starter content', 'coffee-shop' ).'<br>'. esc_html_x( 'Black Tea 12.25', 'Theme starter content', 'coffee-shop' ) . esc_html_x( 'Mint Tea 11.75', 'Theme starter content', 'coffee-shop' ).'<br>'. esc_html_x( 'Espresso 11.25', 'Theme starter content', 'coffee-shop' ).'<br>'. esc_html_x( 'Americano 9.75', 'Theme starter content', 'coffee-shop' ).'<br>'. esc_html_x( 'Latte 8.75', 'Theme starter content', 'coffee-shop' ).'<br>'. esc_html_x( 'Cappuccino 5.99', 'Theme starter content', 'coffee-shop' ). '</p>',
					'<p><a href="#" class="btn btn-default">' . esc_html_x( 'View the Full Menu &rarr;', 'Theme starter content', 'coffee-shop' ) . '</a></p>',
				) ),
			),
			'coffee-chef' => array(
				'post_type' => 'page',
				'post_title' => esc_html_x( 'Chef Preparing Food of a Restaurant', 'Theme starter content', 'coffee-shop' ),
				'post_content' => join( '', array(
					'<p>' . esc_html_x( 'A person sitting over a gourmet meal at a long table with numerous plates and wine glasses.', 'Theme starter content', 'coffee-shop' ) . '</p>',
					'<p><a href="#" class="btn btn-default">' . esc_html_x( 'Learn More &rarr;', 'Theme starter content', 'coffee-shop' ) . '</a></p>',
				) ),
				'thumbnail' => '{{image-chef}}',
			),
			'cranberry_cocktail' => array(
				'post_type' => 'page',
				'post_title' => esc_html_x( 'Cranberry Cocktail', 'Theme starter content', 'coffee-shop' ),
				'post_content' => join( '', array(
					'<p>' . esc_html_x( 'We\'ve collected our favorite cold-weather gin cocktail recipes.', 'Theme starter content', 'coffee-shop' ) . '</p>',
					'<p><a href="#" class="btn btn-default">' . esc_html_x( 'Learn More &rarr;', 'Theme starter content', 'coffee-shop' ) . '</a></p>',
				) ),
				'thumbnail' => '{{image-cocktail}}',
			),
			'blueberry_pastries' => array(
				'post_type' => 'page',
				'post_title' => esc_html_x( 'Blueberry Pastries', 'Theme starter content', 'coffee-shop' ),
				'post_content' => join( '', array(
					'<p>' . esc_html_x( 'I love using puff pastry and find it is so easy to use &#9472; and it was perfect!', 'Theme starter content', 'coffee-shop' ) . '</p>',
					'<p><a href="#" class="btn btn-default">' . esc_html_x( 'Learn More &rarr;', 'Theme starter content', 'coffee-shop' ) . '</a></p>',
				) ),
				'thumbnail' => '{{image-blueberry}}',
			),
			'coffe_shop_toronto' => array(
				'post_type' => 'page',
				'post_title' => esc_html_x( 'Coffee Shop in Toronto', 'Theme starter content', 'coffee-shop' ),
				'post_content' => join( '', array(
					'<p>' . esc_html_x( 'People chatting in a coffee shop in Toronto.', 'Theme starter content', 'coffee-shop' ) . '</p>',
					'<p><a href="#panel-1" class="btn btn-default">' . esc_html_x( 'View the Menu', 'Theme starter content', 'coffee-shop' ) . '</a></p>',
				) ),
				'thumbnail' => '{{image-shop_toronto}}',
			),
			'visit-us' => array(
				'post_type' => 'page',
				'post_title' => esc_html_x( 'Come with us', 'Theme starter content', 'coffee-shop' ),
				'post_content' => join( '', array(
					'<p>' . esc_html_x( '555 Franklin Ave.', 'Theme starter content', 'coffee-shop' ).'<br>'. esc_html_x( 'Brooklyn NY 11230', 'Theme starter content', 'coffee-shop' ).'<br>'. esc_html_x( '(901) 820-0029', 'Theme starter content', 'coffee-shop' ). '</p>',
				) ),
			),
		),

		// Add attachments.
		'attachments' => array(
			'image-small-cafe' => array(
				'post_title' => esc_html_x( 'Small Cafe in the Heart of City!', 'Theme starter content', 'coffee-shop' ),
				'file' => 'assets/img/small-cafe.jpg',
			),
			'image-menu' => array(
				'post_title' => esc_html_x( 'Coffee', 'Theme starter content', 'coffee-shop' ),
				'file' => 'assets/img/menu.jpg',
			),

			'image-chef' => array(
				'post_title' => esc_html_x( 'Chef Preparing Food of a Restaurant', 'Theme starter content', 'coffee-shop' ),
				'file' => 'assets/img/chef_restaurant.jpg',
			),
			'image-cocktail' => array(
				'post_title' => esc_html_x( 'Cranberry Cocktail', 'Theme starter content', 'coffee-shop' ),
				'file' => 'assets/img/cranberry_cocktail.jpg',
			),

			'image-blueberry' => array(
				'post_title' => esc_html_x( 'Blueberry Pastries', 'Theme starter content', 'coffee-shop' ),
				'file' => 'assets/img/blueberry_pastries.jpg',
			),

			'image-shop_toronto' => array(
				'post_title' => esc_html_x( 'Coffee Shop in Toronto', 'Theme starter content', 'coffee-shop' ),
				'file' => 'assets/img/shop_toronto.jpg',
			),

			'image-visit-us' => array(
				'post_title' => esc_html_x( 'Visit Us', 'Theme starter content', 'coffee-shop' ),
				'file' => 'assets/img/visit-us.jpg',
			),
		),

		// Add widgets.
		'widgets' => array(
			'sidebar-3' => array(
				'roastery' => array(
					'text',
					array(
						'title' => esc_html_x( 'Roastery', 'Theme starter content', 'coffee-shop' ),
						'text' => '<p>' . esc_html_x( '555 Franklin Ave.', 'Theme starter content', 'coffee-shop' ) . '<br />' . esc_html_x( 'Brooklyn, NY 11230', 'Theme starter content', 'coffee-shop' ) . '</p>',
					),
				),
			),
			'sidebar-4' => array(
				'hours' => array(
					'text',
					array(
						'title' => esc_html_x( 'Hours', 'Theme starter content', 'coffee-shop' ),
						'text' => '<p>' . esc_html_x( 'Mon&ndash;Fri: 7am&ndash;7pm', 'Theme starter content', 'coffee-shop' ) . '<br />' . esc_html_x( 'Sat&ndash;Sun: 8am&ndash;6pm', 'Theme starter content', 'coffee-shop' ) . '</p>',
					),
				),
			),
			'sidebar-5' => array(
				'contact' => array(
					'text',
					array(
						'title' => esc_html_x( 'Contact', 'Theme starter content', 'coffee-shop' ),
						'text' => '<p>' . esc_html_x( 'info@example.com', 'Theme starter content', 'coffee-shop' ) . '<br />' . esc_html_x( '(901) 820-0029', 'Theme starter content', 'coffee-shop' ) . '</p>',
					),
				),
			),
		),

		// Set the options.
		'options' => array(
			'show_on_front' => 'page',
			'page_on_front' => '{{hero}}',
			'page_for_posts' => '{{blog}}',
		),

		// Set the theme mods.
		'theme_mods' => array(
			// Panlel 0.
			'panel_class_0' => 'panel tall dark align-center no-border',
			'panel_bg_image_0' => '{{image-small-cafe}}',
			'panel_bg_repeat_0' => 'no-repeat',
			'panel_bg_position_0' => 'center center',
			'panel_bg_attachment_0' => 'fixed',
			'panel_bg_size_type_0' => 'cover',
			'panel_bg_opacity_0' => '0.7',

			// Panel 1.
			'panel_content_1' => '{{menu}}',
			'panel_bg_image_1' => '{{image-menu}}',
			'panel_bg_repeat_1' => 'no-repeat',
			'panel_bg_position_1' => 'center center',
			'panel_bg_attachment_1' => 'fixed',
			'panel_bg_size_type_1' => 'cover',
			'panel_bg_opacity_1' => '0.4',
			'panel_class_1' => 'align-center no-border',

			// Panel 2.
			'panel_content_2' => '{{coffee-chef}}',
			'panel_class_2' => 'split-right align-center no-border',

			// Panel 3.
			'panel_content_3' => '{{cranberry_cocktail}}',
			'panel_class_3' => 'split-left align-center no-border',

			// Panel 4.
			'panel_content_4' => '{{blueberry_pastries}}',
			'panel_class_4' => 'split-right align-center no-border',

			// Panel 5.
			'panel_content_5' => '{{coffe_shop_toronto}}',
			'panel_class_5' => 'split-left align-center no-border',

			// Panel 6.
			'panel_content_6' => '{{visit-us}}',
			'panel_class_6' => 'tall dark align-center',
			'panel_bg_image_6' => '{{image-visit-us}}',
			'panel_bg_repeat_6' => 'no-repeat',
			'panel_bg_position_6' => 'center center',
			'panel_bg_attachment_6' => 'scroll',
			'panel_bg_attachment_6' => 'scroll',
			'panel_bg_size_type_6' => 'cover',
			'panel_bg_opacity_6' => '0.5',
		),

		// Set up menus.
		'nav_menus' => array(
			// Assign a menu to the "top" location.
			'primary' => array(
				'name' => __( 'Primary', 'coffee-shop' ),
				'items' => array(
					'link_home',
					'page_menu' => array(
						'type' => 'post_type',
						'object' => 'page',
						'object_id' => '{{menu}}',
					),
					'page_blog',
					'page_about',
					'page_contact',
				),
			),
		),
	);

	/**
	 * Filters the array of starter content.
	 *
	 * @param array $starter_content Array of starter content.
	 */
	$starter_content = apply_filters( 'coffee_starter_content', $starter_content );

	add_theme_support( 'starter-content', $starter_content );
}

add_action( 'after_setup_theme', 'coffee_setup' );

/**
 * Register widget area.
 */
function coffee_widgets_init() {
	// Sidebar
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'coffee-shop' ),
		'id'            => 'sidebar-1',
		'description'   => __( 'Appears on posts and pages', 'coffee-shop' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );

	// Sidebar Category
	register_sidebar( array(
		'name'          => __( 'Sidebar Category', 'coffee-shop' ),
		'id'            => 'sidebar-2',
		'description'   => __( 'Appears on posts and pages', 'coffee-shop' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );

	// Footer widgets.
	for ( $i = 3; $i <= 6; $i++ ) :

	register_sidebar( array(
		'name'          => __( 'Footer', 'coffee-shop' ) . ' ' . ( $i - 2 ),
		'id'            => 'sidebar-' . $i,
		'description'   => __( 'Appears in the footer.', 'coffee-shop' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );

	endfor;

	// Sidebar Single Post
	register_sidebar( array(
		'name'          => __( 'Sidebar Single Post', 'coffee-shop' ),
		'id'            => 'sidebar-7',
		'description'   => __( 'Appears on posts and pages', 'coffee-shop' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );

	// Sidebar Blog
	register_sidebar( array(
		'name'          => __( 'Sidebar Blog', 'coffee-shop' ),
		'id'            => 'sidebar-8',
		'description'   => __( 'Appears on posts and pages', 'coffee-shop' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );

}
add_action( 'widgets_init', 'coffee_widgets_init' );

/**
 * Register Google fonts for Coffee Shop.
 *
 * @return string Google fonts URL for the theme.
 */
function coffee_fonts_url() {
	$fonts_url = '';
	$fonts     = array();
	$subsets   = 'latin,latin-ext';

	/**
	 * Translators: If there are characters in your language that are not
	 * supported by Lato or Open Sans, translate this to 'off'.
	 * Do not translate into your own language.
	 */
	if ( 'off' !== _x( 'on', 'Open Sans font: on or off', 'coffee-shop' ) ) {
		$fonts[] = 'Open Sans:400,400i,700,700i';
	}

	if ( 'off' !== _x( 'on', 'Lato font: on or off', 'coffee-shop' ) ) {
		$fonts[] = 'Lato:400,700,400italic,700italic';
	}

	if ( $fonts ) {
		$fonts_url = add_query_arg( array(
			'family' => urlencode( implode( '|', $fonts ) ),
			'subset' => urlencode( $subsets ),
		), 'https://fonts.googleapis.com/css' );
	}

	return apply_filters( 'coffee_fonts_url', $fonts_url );
}

/**
 * Handles JavaScript detection.
 *
 * Adds a `js` class to the root `<html>` element when JavaScript is detected.
 */
function coffee_javascript_detection() {
	echo "<script>(function(html){html.className = html.className.replace(/\bno-js\b/,'js')})(document.documentElement);</script>\n";
}
add_action( 'wp_head', 'coffee_javascript_detection', 0 );

/**
 * Enqueue scripts and styles.
 */
function coffee_scripts() {
	wp_enqueue_style(
		'coffee-fonts',
		coffee_fonts_url()
	);

	wp_enqueue_style(
		'coffee-font-awesome',
		get_template_directory_uri() . '/assets/fonts/font-awesome/css/font-awesome.css'
	);

	wp_enqueue_style(
		'coffee-style',
		get_stylesheet_uri()
	);

	wp_style_add_data( 'coffee-style', 'rtl', 'replace' );

	wp_enqueue_script(
		'jquery-scrollto',
		get_theme_file_uri( '/assets/js/jquery.scrollTo.js' ),
		array( 'jquery' ),
		'2.1.2',
		true
	);

	wp_enqueue_script(
		'coffee-navigation',
		get_template_directory_uri() . '/assets/js/navigation.js',
		array( 'jquery' ),
		COFFEE_VERSION,
		true
	);

	wp_enqueue_script(
		'coffee-skip-link-focus-fix',
		get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js',
		array(),
		COFFEE_VERSION,
		true
	);

	wp_enqueue_script(
		'coffee-custom',
		get_template_directory_uri() . '/assets/js/custom.js',
		array( 'jquery' ),
		COFFEE_VERSION,
		true
	);

	wp_localize_script( 'coffee-navigation', 'coffeeScreenReaderText', array(
		'menu' => esc_html__( 'Menu', 'coffee-shop' ),
		'close' => esc_html__( 'Close', 'coffee-shop' ),
		'expand' => '<span class="screen-reader-text">' . esc_html__( 'Expand child menu', 'coffee-shop' ) . '</span>',
		'collapse' => '<span class="screen-reader-text">' . esc_html__( 'Collapse child menu', 'coffee-shop' ) . '</span>',
	) );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	// Deregister styles for Jetpack's Infinite Scroll.
	if ( wp_style_is( 'the-neverending-homepage', 'registered' ) ) {
		wp_deregister_style( 'the-neverending-homepage' );
	}

	// Deregister styles for Contact Form 7.
	if ( wp_style_is( 'contact-form-7', 'registered' ) ) {
		wp_deregister_style( 'contact-form-7' );
	}
}
add_action( 'wp_enqueue_scripts', 'coffee_scripts' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer.
 */
require get_template_directory() . '/inc/class-coffee-customize-control-message.php';
require get_template_directory() . '/inc/customizer-sanitization.php';
require get_template_directory() . '/inc/customizer.php';

/**
 * Use front-page.php when Front page displays is set to a static page.
 *
 * @param string $template front-page.php.
 *
 * @return string The template to be used: blank if is_home() is true (defaults to index.php), else $template.
 */
function coffee_front_page_template( $template ) {
	return is_home() ? '' : $template;
}
add_filter( 'frontpage_template', 'coffee_front_page_template' );

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

add_filter('style_loader_tag', 'myplugin_remove_type_attr', 10, 2);
add_filter('script_loader_tag', 'myplugin_remove_type_attr', 10, 2);

function myplugin_remove_type_attr($tag, $handle) {
    return preg_replace( "/type=['\"]text\/(javascript|css)['\"]/", '', $tag );
}

/**
 * Reading
 */

function wporg_settings_init()
{
    // register a new setting for "reading" page
    register_setting('reading', 'wporg_setting_name');
 
    // register a new section in the "reading" page
    add_settings_section(
        'wporg_settings_section',
        'Panels Settings Section',
        'wporg_settings_section_cb',
        'reading'
    );
 
    // register a new field in the "wporg_settings_section" section, inside the "reading" page
    add_settings_field(
        'wporg_settings_field',
        'Front Page Displays Setting',
        'wporg_settings_field_cb',
        'reading',
        'wporg_settings_section'
    );
}
 
/**
 * register wporg_settings_init to the admin_init action hook
 */
add_action('admin_init', 'wporg_settings_init');
 
/**
 * callback functions
 */
 
// section content cb
function wporg_settings_section_cb()
{
    echo '<p>The setting shows how much you need to displays on the main page, the number of panels will be displayed in the customizer.</p>';
}
 
// field content cb
function wporg_settings_field_cb()
{
    // get the value of the setting we've registered with register_setting()
    $setting = get_option('wporg_setting_name');
    // output the field
    if(( $setting == null) OR (!isset($setting))){
    	 $setting = 8;
    	 update_option( 'wporg_setting_name', $setting );
    }
    ?>
    <input type="number" class="small-text" name="wporg_setting_name"  step="1" min="1" max="30" value="<?php echo isset( $setting ) ? esc_attr( $setting ) : ''; ?>"> Panels
    <?php
}