<?php
/**
 * Coffee Shop Theme Customizer
 *
 * @package Coffee Shop
 */

/**
 * Add options to Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function coffee_sanitize_default( $value ) {
	return $value;
}

function coffee_customize_register( $wp_customize ) {
	/**
	 * Site Identity.
	 */
	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';
	//$wp_customize->get_setting( 'header_text' )->transport = 'postMessage';

	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.site-title a',
		'render_callback' => 'coffee_customize_partial_blogname',
	) );

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => '.site-description',
		'render_callback' => 'coffee_customize_partial_blogdescription',
	) );

	/*
	 * Theme Options.
	 */

	$wp_customize->add_panel( 'theme_options' , array(
		'title' => __( 'Theme Options', 'coffee-shop' ),
		'priority' => 140,
	) );

	/**
	 * Front Page.
	 */

	for ( $i = 0; $i <= coffee_get_panel_count(); $i++ ) :

	$wp_customize->add_section( 'panel_' . $i, array(
		'title'           => 0 == $i ? __( 'Hero Panel', 'coffee-shop' ) : __( 'Panel ', 'coffee-shop' ) . $i,
		'panel'           => 'theme_options',
		'active_callback' => 'coffee_is_front_page',
	) );

	if ( 0 !== $i ) :

		$wp_customize->add_setting( 'panel_content_' . $i, array(
			'default' => 0,
			'transport' => 'postMessage',
			'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( 'panel_content_' . $i, array(
			'type' => 'dropdown-pages',
			'label' => esc_html__( 'Content', 'coffee-shop' ),
			'section' => 'panel_' . $i,
			'allow_addition' => true,
		) );

		$wp_customize->selective_refresh->add_partial( 'panel_content_' . $i, array(
			'selector' => '#panel-' . $i,
			'render_callback' => 'coffee_panel',
			'container_inclusive' => true,
		) );

	endif;

	// Background image.
	$wp_customize->add_setting( 'panel_bg_image_' . $i, array(
		'transport' => 'postMessage',
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control(
		new WP_Customize_Media_Control(
			$wp_customize,
			'panel_bg_image_' . $i,
			array(
				'label' => __( 'Background Image', 'coffee-shop' ),
				'section' => 'panel_' . $i,
			)
		)
	);

	$wp_customize->selective_refresh->add_partial( 'panel_bg_image_' . $i, array(
		'selector' => '#panel-' . $i,
		'render_callback' => 'coffee_panel',
		'container_inclusive' => true,
	) );

	// Background repeat.
	$wp_customize->add_setting( 'panel_bg_repeat_' . $i, array(
		'default'           => 'no-repeat',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'coffee_sanitize_background_repeat',
	) );

	$wp_customize->add_control( 'panel_bg_repeat_' . $i, array(
		'label'   => __( 'Background Repeat', 'coffee-shop' ),
		'section' => 'panel_' . $i,
		'type'    => 'select',
		'choices' => array(
			'no-repeat' => __( 'No Repeat', 'coffee-shop' ),
			'repeat'    => __( 'Tile', 'coffee-shop' ),
			'repeat-x'  => __( 'Tile Horizontally', 'coffee-shop' ),
			'repeat-y'  => __( 'Tile Vertically', 'coffee-shop' ),
		),
	) );

	// Background position.
	$wp_customize->add_setting( 'panel_bg_position_' . $i, array(
		'default'           => 'left top',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'coffee_sanitize_background_position',
	) );

	$wp_customize->add_control( 'panel_bg_position_' . $i, array(
		'label'   => __( 'Background Position', 'coffee-shop' ),
		'section' => 'panel_' . $i,
		'type'    => 'select',
		'choices' => array(
			'left top'      => __( 'Left Top', 'coffee-shop' ),
			'left center'   => __( 'Left Center', 'coffee-shop' ),
			'left bottom'   => __( 'Left Bottom', 'coffee-shop' ),
			'center top'    => __( 'Center Top', 'coffee-shop' ),
			'center center' => __( 'Center Center', 'coffee-shop' ),
			'center bottom' => __( 'Center Bottom', 'coffee-shop' ),
			'right top'     => __( 'Right Top', 'coffee-shop' ),
			'right center'  => __( 'Right Center', 'coffee-shop' ),
			'right bottom'  => __( 'Right Bottom', 'coffee-shop' ),
		),
	) );

	// Background attachment.
	$wp_customize->add_setting( 'panel_bg_attachment_' . $i, array(
		'default'           => 'scroll',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'coffee_sanitize_background_attachment',
	) );

	$wp_customize->add_control( 'panel_bg_attachment_' . $i, array(
		'label'   => __( 'Background Attachment', 'coffee-shop' ),
		'section' => 'panel_' . $i,
		'type'    => 'select',
		'choices' => array(
			'scroll' => __( 'Scroll', 'coffee-shop' ),
			'fixed'  => __( 'Fixed', 'coffee-shop' ),
		),
	) );

	// Background size type.
	$wp_customize->add_setting( 'panel_bg_size_type_' . $i, array(
		'default'           => 'auto',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'coffee_sanitize_background_size_type',
	) );

	$wp_customize->add_control( 'panel_bg_size_type_' . $i, array(
		'label'   => __( 'Background Size', 'coffee-shop' ),
		'section' => 'panel_' . $i,
		'type'    => 'select',
		'choices' => array(
			'auto'    => __( 'Auto', 'coffee-shop' ),
			'cover'   => __( 'Cover', 'coffee-shop' ),
			'percent' => __( 'Percent', 'coffee-shop' ),
		),
	) );

	// Background size in percent.
	$wp_customize->add_setting( 'panel_bg_size_' . $i, array(
		'default'           => 1,
		'transport'         => 'postMessage',
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control( 'panel_bg_size_' . $i, array(
		'label'   => __( 'Background Size %', 'coffee-shop' ),
		'section' => 'panel_' . $i,
		'type'    => 'range',
		'input_attrs' => array(
			'min'  => 0,
			'max'  => 100,
			'step' => 1,
		),
	) );

	// Background opacity.
	$wp_customize->add_setting( 'panel_bg_opacity_' . $i, array(
		'default'           => 1,
		'transport'         => 'postMessage',
		'sanitize_callback' => 'coffee_sanitize_opacity_range',
	) );

	$wp_customize->add_control( 'panel_bg_opacity_' . $i, array(
		'label'   => __( 'Background Opacity', 'coffee-shop' ),
		'section' => 'panel_' . $i,
		'type'    => 'range',
		'input_attrs' => array(
			'min'   => 0,
			'max'   => 1,
			'step'  => 0.02,
		),
	) );

	// CSS class.
	$wp_customize->add_setting( 'panel_class_' . $i, array(
		'default' => '',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );

	$wp_customize->add_control( 'panel_class_' . $i, array(
		'type' => 'text',
		'label' => esc_html__( 'Additional CSS Classes', 'coffee-shop' ),
		'section' => 'panel_' . $i,
		"description" => sprintf( wp_kses( __( 'Space-separated list of CSS classes applied to the panel. <a href="%s" target="_blank">Learn more &rarr;</a>', 'coffee-shop' ), array( 'a' => array( 'href' => array() ) ) ), 'https://docs.themepatio.com/' ),

	) );

	$wp_customize->selective_refresh->add_partial( 'panel_class_' . $i, array(
		'selector' => '#panel-' . $i,
		'render_callback' => 'coffee_panel',
		'container_inclusive' => true,
	) );

	endfor;

// Blog Options.

	$wp_customize->add_section( 'blog' , array(
		'title' => __( 'Blog Options', 'coffee-shop' ),
		'priority' => 145,
		'description' => __( 'You can customize the display of the blog.', 'coffee-shop' ),
	) );

	$wp_customize->add_setting( 'coffee_blog_layout', array(
		'default' => 'list',
		'sanitize_callback' => 'coffee_sanitize_default'
	) );

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'coffee_blog_layout',
			array(
				'label'      => esc_html__('Blog Layout', 'coffee-shop'),
				'section'    => 'blog',
				'settings'   => 'coffee_blog_layout',
				'type'       => 'select', 
				'choices'    => array( 
					'grid'            => esc_html__('Grid', 'coffee-shop'), 
					'list'            => esc_html__('List', 'coffee-shop'),
					)
				)
			)
		);

// Footer Options.

	$wp_customize->add_section( 'footer' , array(
		'title' => __( 'Footer Options', 'coffee-shop' ),
		'priority' => 150,
		'description' => __( 'Enter your copyright.', 'coffee-shop' ),
	) );

	$wp_customize->add_setting( 'coffee_footer_copyright', array(
		'default' => 'Coffee Shop WordPress Theme',
		'sanitize_callback' => 'coffee_sanitize_default'
	) );

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'coffee_footer_copyright',
			array(
				'label'      => esc_html__('Copyright Text', 'coffee-shop'),
				'section'    => 'footer',
				'settings'   => 'coffee_footer_copyright',
				'type'		 => 'text'
				)
			)
	);


	// Accent Colors

	$wp_customize->add_control(
		new Coffee_Customize_Control_Message(
			$wp_customize,
			'blog',
			array(
				'label'       => __( 'Accent Colors', 'coffee-shop' ),
				'section'     => 'colors',
				'settings'    => array(),
				'description' => __( 'Customize the colors of the your blog.', 'coffee-shop' ),
			)
		)
	);

	$wp_customize->add_setting( 'coffee_accent_color', array(
		'default'           => '#444444',
		'sanitize_callback' => 'coffee_sanitize_default'
	) ); 

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'coffee_accent_color',
			array(
				'label'      => esc_html__('Link Color', 'coffee-shop'),
				'section'    => 'colors',
				'settings'   => 'coffee_accent_color',
				'priority'	 => 10
				)
			)
	);

	$wp_customize->add_setting( 'coffee_accent_hover_color', array(
		'default'           => '#7d7c7c',
		'sanitize_callback' => 'coffee_sanitize_default'
	) ); 

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'coffee_accent_hover_color',
			array(
				'label'      => esc_html__('Hover Link Color', 'coffee-shop'),
				'section'    => 'colors',
				'settings'   => 'coffee_accent_hover_color',
				'priority'	 => 15
				)
			)
	);

}
add_action( 'customize_register', 'coffee_customize_register' );


/**
 * Binds js handlers to make theme customizer preview reload changes asynchronously.
 */
function coffee_customize_preview_js() {
	wp_enqueue_script(
		'coffee_customizer',
		get_template_directory_uri() . '/assets/js/customizer-preview.js',
		array( 'coffee-preview' ),
		COFFEE_VERSION,
		true
	);
	wp_localize_script( 'coffee_customizer', 'coffeePanelCount', array( coffee_get_panel_count() ) );
}
add_action( 'customize_preview_init', 'coffee_customize_preview_js' );

/**
 * Enqueue custom scripts for customizer controls.
 */
function coffee_customizer_scripts() {
	wp_enqueue_script(
		'coffee-customizer-controls',
		get_template_directory_uri() . '/assets/js/customizer-controls.js',
		array( 'jquery', 'customize-controls' ),
		COFFEE_VERSION,
		true
	);
	wp_localize_script( 'coffee-customizer-controls', 'coffeePanelCount', array( coffee_get_panel_count() ) );

	// Custom CSS for the Customizer controls.
	wp_enqueue_style(
		'coffee-customizer-styles',
		get_template_directory_uri() . '/assets/css/customizer.css'
	);
}
add_action( 'customize_controls_enqueue_scripts', 'coffee_customizer_scripts' );
